@@ -28,13 +28,10 @@
  * @Short_Description: Image data content
  *
  * #ClutterImage is a #ClutterContent implementation that displays
- * image data.
+ * image data inside a #ClutterActor.
  *
- * <informalexample><programlisting>
- * <xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" href="../../../../examples/image-content.c">
- *   <xi:fallback>FIXME: MISSING XINCLUDE CONTENT</xi:fallback>
- * </xi:include>
- * </programlisting></informalexample>
+ * See [image.c](https://git.gnome.org/browse/clutter/tree/examples/image.c?h=clutter-1.18)
+ * for an example of how to use #ClutterImage.
  *
  * #ClutterImage is available since Clutter 1.10.
  */
@@ -119,9 +116,12 @@ clutter_image_paint_content (ClutterContent   *content,
   clutter_actor_get_content_scaling_filters (actor, &min_f, &mag_f);
   repeat = clutter_actor_get_content_repeat (actor);
 
-  color.red = paint_opacity;
-  color.green = paint_opacity;
-  color.blue = paint_opacity;
+  /* ClutterTextureNode will premultiply the blend color, so we
+   * want it to be white with the paint opacity
+   */
+  color.red = 255;
+  color.green = 255;
+  color.blue = 255;
   color.alpha = paint_opacity;
 
   node = clutter_texture_node_new (priv->texture, &color, min_f, mag_f);
