@@ -46,7 +46,7 @@ typedef struct _ClutterTransitionClass          ClutterTransitionClass;
 /**
  * ClutterTransition:
  *
- * The <structname>ClutterTransition</structname> structure contains private
+ * The #ClutterTransition structure contains private
  * data and should only be accessed using the provided API.
  *
  * Since: 1.10
@@ -68,7 +68,7 @@ struct _ClutterTransition
  * @compute_value: virtual function; called each frame to compute and apply
  *   the interpolation of the interval
  *
- * The <structname>ClutterTransitionClass</structname> structure contains
+ * The #ClutterTransitionClass structure contains
  * private data.
  *
  * Since: 1.10
@@ -101,6 +101,21 @@ void                    clutter_transition_set_interval                 (Clutter
                                                                          ClutterInterval   *interval);
 CLUTTER_AVAILABLE_IN_1_10
 ClutterInterval *       clutter_transition_get_interval                 (ClutterTransition *transition);
+CLUTTER_AVAILABLE_IN_1_12
+void                    clutter_transition_set_from_value               (ClutterTransition *transition,
+                                                                         const GValue      *value);
+CLUTTER_AVAILABLE_IN_1_12
+void                    clutter_transition_set_to_value                 (ClutterTransition *transition,
+                                                                         const GValue      *value);
+CLUTTER_AVAILABLE_IN_1_12
+void                    clutter_transition_set_from                     (ClutterTransition *transition,
+                                                                         GType              value_type,
+                                                                         ...);
+CLUTTER_AVAILABLE_IN_1_12
+void                    clutter_transition_set_to                       (ClutterTransition *transition,
+                                                                         GType              value_type,
+                                                                         ...);
+
 CLUTTER_AVAILABLE_IN_1_10
 void                    clutter_transition_set_animatable               (ClutterTransition *transition,
                                                                          ClutterAnimatable *animatable);
