@@ -96,14 +96,14 @@ G_BEGIN_DECLS
  *
  * The micro version of the Clutter library (3, if %CLUTTER_VERSION is 1.2.3)
  */
-#define CLUTTER_MICRO_VERSION   (0)
+#define CLUTTER_MICRO_VERSION   (2)
 
 /**
  * CLUTTER_VERSION:
  *
  * The full version of the Clutter library, like 1.2.3
  */
-#define CLUTTER_VERSION         1.18.0
+#define CLUTTER_VERSION         1.18.2
 
 /**
  * CLUTTER_VERSION_S:
@@ -111,7 +111,7 @@ G_BEGIN_DECLS
  * The full version of the Clutter library, in string form (suited for
  * string concatenation)
  */
-#define CLUTTER_VERSION_S       "1.18.0"
+#define CLUTTER_VERSION_S       "1.18.2"
 
 /**
  * CLUTTER_VERSION_HEX:
@@ -258,7 +258,19 @@ G_BEGIN_DECLS
 #define _CLUTTER_EXTERN extern
 #endif
 
-#define CLUTTER_VAR _CLUTTER_EXTERN
+#ifdef CLUTTER_WINDOWING_WIN32
+# ifdef CLUTTER_COMPILATION
+#  ifdef DLL_EXPORT
+#   define CLUTTER_VAR __declspec(dllexport)
+#  else
+#   define CLUTTER_VAR extern
+#  endif
+# else
+#  define CLUTTER_VAR __declspec(dllimport)
+# endif
+#else
+# define CLUTTER_VAR _CLUTTER_EXTERN
+#endif
 
 /**
  * clutter_major_version:
