@@ -41,7 +41,7 @@
 #include "cogl/clutter-stage-cogl.h"
 
 #ifdef HAVE_EVDEV
-#include "clutter-device-manager-evdev.h"
+#include "evdev/clutter-device-manager-evdev.h"
 #endif
 
 #include "clutter-debug.h"
@@ -53,10 +53,16 @@
 #include "clutter-egl.h"
 #endif
 
+#include "clutter-stage-eglnative.h"
+
 #define clutter_backend_egl_native_get_type     _clutter_backend_egl_native_get_type
 
 G_DEFINE_TYPE (ClutterBackendEglNative, clutter_backend_egl_native, CLUTTER_TYPE_BACKEND);
 
+#ifdef COGL_HAS_EGL_PLATFORM_KMS_SUPPORT
+static int _kms_fd = -1;
+#endif
+
 static void
 clutter_backend_egl_native_dispose (GObject *gobject)
 {
@@ -71,6 +77,25 @@ clutter_backend_egl_native_dispose (GObject *gobject)
   G_OBJECT_CLASS (clutter_backend_egl_native_parent_class)->dispose (gobject);
 }
 
+static CoglRenderer *
+clutter_backend_egl_native_get_renderer (ClutterBackend  *backend,
+                                         GError         **error)
+{
+  CoglRenderer *renderer;
+
+  renderer = cogl_renderer_new ();
+
+#ifdef COGL_HAS_EGL_PLATFORM_KMS_SUPPORT
+  if (_kms_fd > -1)
+    {
+      cogl_renderer_set_winsys_id (renderer, COGL_WINSYS_ID_EGL_KMS);
+      cogl_kms_renderer_set_kms_fd (renderer, _kms_fd);
+    }
+#endif
+
+  return renderer;
+}
+
 static void
 clutter_backend_egl_native_class_init (ClutterBackendEglNativeClass *klass)
 {
@@ -79,7 +104,9 @@ clutter_backend_egl_native_class_init (ClutterBackendEglNativeClass *klass)
 
   gobject_class->dispose = clutter_backend_egl_native_dispose;
 
-  backend_class->stage_window_type = CLUTTER_TYPE_STAGE_COGL;
+  backend_class->stage_window_type = CLUTTER_TYPE_STAGE_EGL_NATIVE;
+
+  backend_class->get_renderer = clutter_backend_egl_native_get_renderer;
 }
 
 static void
@@ -157,3 +184,23 @@ clutter_egl_get_egl_display (void)
   return 0;
 #endif
 }
+
+#ifdef COGL_HAS_EGL_PLATFORM_KMS_SUPPORT
+/**
+ * clutter_egl_set_kms_fd:
+ * @fd: The fd to talk to the kms driver with
+ *
+ * Sets the fd that Cogl should use to talk to the kms driver.
+ * Setting this to a negative value effectively reverts this
+ * call, making Cogl open the device itself.
+ *
+ * This can only be called before clutter_init() is called.
+ *
+ * Since: 1.18
+ */
+void
+clutter_egl_set_kms_fd (int fd)
+{
+  _kms_fd = fd;
+}
+#endif
