@@ -44,6 +44,7 @@
 #include "clutter-backend-wayland.h"
 #include "clutter-backend-wayland-priv.h"
 #include "clutter-stage-private.h"
+#include "clutter-stage-wayland.h"
 #include "clutter-wayland.h"
 
 #include "cogl/clutter-stage-cogl.h"
@@ -106,6 +107,7 @@ clutter_wayland_handle_button (void *data,
   ClutterStageCogl          *stage_cogl;
   ClutterEvent              *event;
   ClutterEventType           type;
+  ClutterModifierType        modifier_mask = 0;
 
   if (!device->pointer_focus)
     return;
@@ -129,15 +131,28 @@ clutter_wayland_handle_button (void *data,
   switch (button) {
   case 272:
     event->button.button = 1;
+    modifier_mask = CLUTTER_BUTTON1_MASK;
     break;
   case 273:
     event->button.button = 3;
+    modifier_mask = CLUTTER_BUTTON2_MASK;
     break;
   case 274:
     event->button.button = 2;
+    modifier_mask = CLUTTER_BUTTON3_MASK;
     break;
   }
 
+  if (modifier_mask)
+    {
+      if (state)
+        device->button_modifier_state |= modifier_mask;
+      else
+        device->button_modifier_state &= ~modifier_mask;
+    }
+
+  event->button.modifier_state = device->button_modifier_state;
+
   _clutter_event_push (event, FALSE);
 }
 
@@ -351,15 +366,17 @@ clutter_wayland_handle_pointer_enter (void *data,
                                       wl_fixed_t x, wl_fixed_t y)
 {
   ClutterInputDeviceWayland *device = data;
+  ClutterStageWayland       *stage_wayland;
   ClutterStageCogl          *stage_cogl;
   ClutterEvent              *event;
   ClutterBackend            *backend;
   ClutterBackendWayland     *backend_wayland;
 
-  if (!CLUTTER_IS_STAGE_COGL (wl_surface_get_user_data (surface)))
-    return;
+  stage_wayland = wl_surface_get_user_data (surface);
 
-  stage_cogl = wl_surface_get_user_data (surface);
+  if (!CLUTTER_IS_STAGE_COGL (stage_wayland))
+    return;
+  stage_cogl = CLUTTER_STAGE_COGL (stage_wayland);
 
   device->pointer_focus = stage_cogl;
   _clutter_input_device_set_stage (CLUTTER_INPUT_DEVICE (device),
@@ -378,26 +395,35 @@ clutter_wayland_handle_pointer_enter (void *data,
 
   _clutter_event_push (event, FALSE);
 
-  /* Set the cursor to the cursor loaded at backend initialisation */
-  backend = clutter_get_default_backend ();
-  backend_wayland = CLUTTER_BACKEND_WAYLAND (backend);
+  if (stage_wayland->cursor_visible)
+    {
+      /* Set the cursor to the cursor loaded at backend initialisation */
+      backend = clutter_get_default_backend ();
+      backend_wayland = CLUTTER_BACKEND_WAYLAND (backend);
 
-  wl_pointer_set_cursor (pointer,
-                         serial,
-                         backend_wayland->cursor_surface,
-                         backend_wayland->cursor_x,
-                         backend_wayland->cursor_y);
-  wl_surface_attach (backend_wayland->cursor_surface,
-                     backend_wayland->cursor_buffer,
-                     0,
-                     0);
-  wl_surface_damage (backend_wayland->cursor_surface,
-                     0,
-                     0,
-                     32, /* XXX: FFS */
-                     32);
+      _clutter_backend_wayland_ensure_cursor (backend_wayland);
 
-  wl_surface_commit (backend_wayland->cursor_surface);
+      wl_pointer_set_cursor (pointer,
+                             serial,
+                             backend_wayland->cursor_surface,
+                             backend_wayland->cursor_x,
+                             backend_wayland->cursor_y);
+      wl_surface_attach (backend_wayland->cursor_surface,
+                         backend_wayland->cursor_buffer,
+                         0,
+                         0);
+      wl_surface_damage (backend_wayland->cursor_surface,
+                         0,
+                         0,
+                         32, /* XXX: FFS */
+                         32);
+
+      wl_surface_commit (backend_wayland->cursor_surface);
+    }
+  else
+    {
+      wl_pointer_set_cursor (pointer, serial, NULL, 0, 0);
+    }
 }
 
 static void
